| summary.miceFast_pool | R Documentation |
Displays the full pooling diagnostics including within- and between-imputation variance, relative increase in variance, proportion of variance due to missingness, fraction of missing information, and confidence intervals.
## S3 method for class 'miceFast_pool'
summary(object, ...)
object |
an object of class |
... |
additional arguments (currently ignored). |
Invisibly returns the full diagnostics data.frame.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.