| neibo | R Documentation |
This function uses pre-sorting of y and binary search to find one of the k closest values for each miss.
neibo(y, miss, k)
y |
numeric vector values to be looked up |
miss |
numeric vector values to be looked for |
k |
integer number of nearest neighbours to sample from |
a numeric vector
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.